"""
sheet_instances.py
"""

population = [
    # us sizes in landscape
    {'Name': 'letter', 'Group': 'us', 'Height': '8.5', 'Width': '11', 'Size group': 'small'},
    {'Name': 'tabloid', 'Group': 'us', 'Height': '11', 'Width': '17', 'Size group': 'medium'},
    # The following are architectural sizes
    {'Name': 'C', 'Group': 'us', 'Height': '18', 'Width': '24', 'Size group': 'large'},
    {'Name': 'D', 'Group': 'us', 'Height': '24', 'Width': '36', 'Size group': 'large'},
    {'Name': 'E', 'Group': 'us', 'Height': '36', 'Width': '48', 'Size group': 'large'},

    # International sizes landscape
    {'Name': 'A4', 'Group': 'int', 'Height': '210', 'Width': '297', 'Size group': 'small'},
    {'Name': 'A3', 'Group': 'int', 'Height': '297', 'Width': '420', 'Size group': 'medium'},
    {'Name': 'A2', 'Group': 'int', 'Height': '420', 'Width': '594', 'Size group': 'medium'},
    {'Name': 'A1', 'Group': 'int', 'Height': '594', 'Width': '841', 'Size group': 'large'},
    {'Name': 'A0', 'Group': 'int', 'Height': '841', 'Width': '1189', 'Size group': 'large'},
]
